@@ -42,6 +42,7 @@ stored together with [refMingusContainersInstrument Instruments] in \
 
 	def __init__(self, key = 'C', meter=(4,4)):
 
+		#warning should check types
 		if type(key) == str:
 			key = Note(key)
 		self.key = key
@@ -60,7 +61,7 @@ stored together with [refMingusContainersInstrument Instruments] in \
 This function will set the meter of this bar. If the format \
 of the meter is not recognised, a !MeterFormatError will \
 be raised."""
-
+		#warning should raise exception
 		if _meter.valid_beat_duration(meter[1]):
 			self.meter = (meter[0], meter[1])
 			self.length = meter[0] * (1.0 / meter[1])
@@ -79,7 +80,8 @@ NoteContainer]. Raises a !MeterFormatError if the duration is not \
 valid. Returns True if succesful, False otherwise (ie. the Bar \
 hasn't got enough room for a note of that duration.)"""
 
-		# note should be able to be strings, lists, Notes or NoteContainers
+		# note should be able to be one of strings, lists, 
+		# Notes or NoteContainers
 		if hasattr(notes, "notes"):
 			pass
 		elif hasattr(notes, "name"):
@@ -122,8 +124,10 @@ in the Bar"""
 [refMingusContainersNotecontainer NoteContainer], True otherwise."""
 		if self.length == 0.0:
 			return False
-		
-		if self.current_beat + 1.0 / self.bars[-1][1] == self.length:
+	
+		if len(self.bar) == 0:
+			return False
+		if self.current_beat + 1.0 / self.bar[-1][1] == self.length:
 			return True
 
 		return False
